==> just_update_arch-0.1.0.tar.gz: just_update_arch-0.1.0/README.md <==
# Just Update Arch

[![Ko-Fi](https://img.shields.io/badge/donate-kofi-blue?style=for-the-badge&logo=ko-fi&color=e57578&logoColor=FFFFFF&labelColor=262a35)](https://ko-fi.com/molasses)
[![Patreon](https://img.shields.io/badge/donate-patreon-blue?style=for-the-badge&logo=patreon&color=e57578&logoColor=FFFFFF&labelColor=262a35)](https://www.patreon.com/molasseslover)
[![PyPi](https://img.shields.io/badge/install-pypi-blue?style=for-the-badge&logo=python&color=e57578&logoColor=FFFFFF&labelColor=262a35)](https://pypi.org/project/just_update_arch)

Updates packages from the [Arch User Repository](https://aur.archlinux.org/), alongside
the vanilla arch packages, installed as normal through [`pacman`](https://wiki.archlinux.org/title/pacman).

## Usage

There is no complexity to this script, all you have to do is run the command:
```sh
➜ just_update_arch
```

## Installation

The [`src/cli.py`](https://github.com/MolassesLover/JustUpdateArch/blob/master/src/cli.py) file can be installed as the
`just_update_arch` command using `pip`.

You can install it from [GitHub](https://github.com/MolassesLover/JustUpdateArch):
```sh
➜ pip install git+https://github.com/MolassesLover/JustUpdateArch.git
```
Alternatively, from [PyPi](https://pypi.org/project/just_update_arch):
```sh
➜ pip install just_update_arch
```

## License
All files within this repository are licensed under the
[GNU General Public License v3.0](`LICENSE.md`).

## Contributing
Contributions are open, just make sure to sign your
commits, otherwise, your changes will not be merged.

==> just_update_arch-0.1.1.tar.gz: just_update_arch-0.1.1/README.md <==
# Just Update Arch

[![Ko-Fi](https://img.shields.io/badge/donate-kofi-blue?style=for-the-badge&logo=ko-fi&color=e57578&logoColor=FFFFFF&labelColor=262a35)](https://ko-fi.com/molasses)
[![Patreon](https://img.shields.io/badge/donate-patreon-blue?style=for-the-badge&logo=patreon&color=e57578&logoColor=FFFFFF&labelColor=262a35)](https://www.patreon.com/molasseslover)
[![PyPi](https://img.shields.io/badge/install-pypi-blue?style=for-the-badge&logo=python&color=e57578&logoColor=FFFFFF&labelColor=262a35)](https://pypi.org/project/just-update-arch/)

Updates packages from the [Arch User Repository](https://aur.archlinux.org/), alongside
the vanilla arch packages, installed as normal through [`pacman`](https://wiki.archlinux.org/title/pacman).

## Usage

There is no complexity to this script, all you have to do is run the command:
```sh
➜ just_update_arch
```

## Installation

The [`src/cli.py`](https://github.com/MolassesLover/JustUpdateArch/blob/master/src/cli.py) file can be installed as the
`just_update_arch` command using `pip`.

You can install it from [GitHub](https://github.com/MolassesLover/JustUpdateArch):
```sh
➜ pip install git+https://github.com/MolassesLover/JustUpdateArch.git
```
Alternatively, from [PyPi](https://pypi.org/project/just_update_arch):
```sh
➜ pip install just-update-arch
```

## License
All files within this repository are licensed under the
[GNU General Public License v3.0](`LICENSE.md`).

## Contributing
Contributions are open, just make sure to sign your
commits, otherwise, your changes will not be merged.
